/*
 * acltool.h
 *
 * Copyright (c) 2019-2020, Peter Eriksson <pen@lysator.liu.se>
 *
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef ACLTOOL_H
#define ACLTOOL_H 1

#include <sys/types.h>
#include <sys/stat.h>

#include "vfs.h"
#include "gacl.h"
#include "argv.h"
#include "commands.h"
#include "aclcmds.h"
#include "basic.h"
#include "strings.h"
#include "misc.h"
#include "opts.h"
#include "common.h"
#include "error.h"


struct command;

typedef struct config {
  int f_debug;
  int f_verbose;
  int f_force;
  int f_print;
  int f_sort;
  int f_merge;
  int f_recurse;
  int f_relaxed;
  int f_noupdate;
  int f_noprefix;
  mode_t f_filetype;
  GACL_STYLE f_style;
  
  int max_depth;
} CONFIG;


extern char *argv0;

extern OPTION global_options[];

/* Default configuration loaded from config file and global command line */
extern CONFIG default_config;

/* Per-command active configuration */
extern CONFIG config;

extern int
error(int rc, int ec, const char *msg, ...);

#endif
